@@ -179,7 +179,7 @@ static int dequote(char *inplace) {
         *q++= *p++; continue;
       } else {
 	while (*p==' ' || *p=='\t') p++;
-	assert(*p=='\n');
+	v= *p++; assert(v=='\n');
       }
     }
   }
